==> arabic_phonetiser-1.0.2.tar.gz: arabic_phonetiser-1.0.2/README.md <==
# Arabic Phonetiser

## Introduction

This package is a Python library for phonetising Arabic text, with a focus on dialects like the Iraqi dialect. It is a fork of Nawar Halabi's [Arabic-Phonetiser](https://github.com/nawarhalabi/Arabic-Phonetiser), but differs in that it is simplified and includes characters commonly used in Arabic dialects.

## Features

- **Simplified Phonetisation**: The phonetisation process has been simplified.

- **Support for Additional Arabic Characters**: This package extends the standard Arabic character set to include characters that are specific to various Arabic dialects, such as the Iraqi dialect. These additional characters are:
    - Buckwalter: `u'C'`, Arabic: 'چ', used in words like چاي
    - Buckwalter: `u'G'`, Arabic: 'گ', used in words like گول
    - Buckwalter: `u'P'`, Arabic: 'پ', used in words like پپسي
    - Buckwalter: `u'V'`, Arabic: 'ڤ', used in words like ڤيتامين
    - Buckwalter: `u'ı'`, Arabic: 'ـ', known as Taweel, used exclusively in dialectal Arabic as a vowel. Its pronunciation is similar to the 'ı' in Turkish.
    
- **Utilizes the [arabic-buckwalter-transliteration](https://github.com/hayderkharrufa/arabic-buckwalter-transliteration/tree/main) package for supporting these new characters.**

## Installation

```bash
pip install arabic-phonetiser
```

## Usage

Here is a simple example:

```python
import arabic_phonetiser

arabic_text = "أگُلّـچْ يَبـنْتي وأَسَمْعـچْ يَچَنْتي"
phon_text = arabic_phonetiser.arabic_to_phonemes(arabic_text)
print(phon_text)
```

Output:

```
< a G u ll ı C + y a b ı n t ii + uu < a s a m E ı C + y a C a n t ii
```

## License

This work is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License. The original work is by Nawar Halabi. For the full license text, please see the LICENSE file in the repository.

## Acknowledgements

This work is a fork of [Nawar Halabi's Arabic-Phonetiser](https://github.com/nawarhalabi/Arabic-Phonetiser). Special thanks to Nawar Halabi for the original work.

==> arabic_phonetiser-1.0.5.tar.gz: arabic_phonetiser-1.0.5/README.md <==
# Arabic Phonetiser

## Introduction

This package is a Python library for phonetising Arabic text, with a focus on dialects like the Iraqi dialect. It is a fork of Nawar Halabi's [Arabic-Phonetiser](https://github.com/nawarhalabi/Arabic-Phonetiser), but differs in that it is simplified and includes characters commonly used in Arabic dialects.

## Features

- **Simplified Phonetisation**: The phonetisation process has been simplified.

- **Support for Additional Arabic Characters**: This package extends the standard Arabic character set to include characters that are specific to various Arabic dialects, such as the Iraqi dialect. These additional characters are:
    - Buckwalter: `u'C'`, Arabic Script: 'چ'
    - Buckwalter: `u'G'`, Arabic Script: 'گ'
    - Buckwalter: `u'P'`, Arabic Script: 'پ'
    - Buckwalter: `u'V'`, Arabic Script: 'ڤ'
    - Buckwalter: `u'ı'`, Arabic Script: 'ـ', known as Taweel, used here as a vowel. Pronunciation is similar to 'ı' in Turkish.
    - Buckwalter: `u'L'`, Arabic Script: 'ڵ'
    - Buckwalter: `u'O'`, Arabic Script: 'ۆ'
    - Buckwalter: `u'e'`, Arabic Script: 'ێ'

    
- **Utilizes the [arabic-buckwalter-transliteration](https://github.com/hayderkharrufa/arabic-buckwalter-transliteration/tree/main) package for supporting these new characters.**

## Installation

```bash
pip install arabic-phonetiser
```

## Usage

Here is a simple example:

```python
import arabic_phonetiser

arabic_text = "أگُلّـچْ يَبـنْتي وأَسَمْعـچْ يَچَنْتي"
phon_text = arabic_phonetiser.arabic_to_phonemes(arabic_text)
print(phon_text)
```

Output:

```
< a G u0 ll ı C + y a b ı n t ii0 + uu0 < a s a m E ı C + y a C a n t ii0
```

## License

This work is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License. The original work is by Nawar Halabi. For the full license text, please see the LICENSE file in the repository.

## Acknowledgements

This work is a fork of [Nawar Halabi's Arabic-Phonetiser](https://github.com/nawarhalabi/Arabic-Phonetiser). Special thanks to Nawar Halabi for the original work.
